# streamlit-chess
Bi-directional component to play chess in streamlit apps

## References
- https://levelup.gitconnected.com/how-to-create-a-simple-chess-app-with-react-e18c0179b167
- https://chessboardjsx.com/integrations/move-validation
- https://github.com/varunpvp/random-chess/blob/main/src/App.tsx
- https://docs.streamlit.io/en/stable/develop_streamlit_components.html#create-a-static-component

## Alternatives to chessboardjsx
- https://stackblitz.com/edit/react-chess-board
- https://github.com/rexxars/react-chess
- Chessboardjsx with move validation https://codesandbox.io/s/x332zqpkl4?file=/src/integrations/WithMoveValidation.js
- https://github.com/ginger-gm/react-chessboardjs-wrapper
- https://ildar-icoosoft.github.io/react-chessboard/?path=/story/board--simple-board